@@ -5,7 +5,7 @@ use warnings;
 use UR;
 use File::Basename qw/basename/;
 
-our $VERSION = "0.30"; # UR $VERSION;
+our $VERSION = "0.33"; # UR $VERSION;
 
 class Command::Tree {
     is => 'Command::V2',
@@ -13,21 +13,6 @@ class Command::Tree {
     doc => 'base class for commands which delegate to sub-commands',
 };
 
-
-sub _execute_with_shell_params_and_return_exit_code {
-    my $class = shift;
-    my @argv = @_;
-
-    # make --foo=bar equivalent to --foo bar
-    @argv = map { ($_ =~ /^(--\w+?)\=(.*)/) ? ($1,$2) : ($_) } @argv;
-    my ($delegate_class, $params) = $class->resolve_class_and_params_for_argv(@argv);
-
-    my $rv = $class->_execute_delegate_class_with_params($delegate_class,$params);
-    
-    my $exit_code = $delegate_class->exit_code_for_return_value($rv);
-    return $exit_code;
-}
-
 sub resolve_class_and_params_for_argv {
     # This is used by execute_with_shell_params_and_exit, but might be used within an application.
     my $self = shift;
@@ -40,84 +25,16 @@ sub resolve_class_and_params_for_argv {
         return $class_for_sub_command->resolve_class_and_params_for_argv(@argv);
     }
     else {
+        # error
         return ($self,undef);
     }
 }
 
-sub _execute_delegate_class_with_params {
-    # this is called by both the shell dispatcher and http dispatcher for now
-    my ($class, $delegate_class, $params) = @_;
-
-    $delegate_class->dump_status_messages(1);
-    $delegate_class->dump_warning_messages(1);
-    $delegate_class->dump_error_messages(1);
-    $delegate_class->dump_debug_messages(0);
-
-    unless ($delegate_class) {
-        $class->usage_message($class->help_usage_complete_text);
-        return;
-    }
-
-    if ( $delegate_class->is_sub_command_delegator && !defined($params) ) {
-        my $command_name = $delegate_class->command_name;
-        $delegate_class->status_message($delegate_class->help_usage_complete_text);
-        $delegate_class->error_message("Please specify a valid sub-command for '$command_name'.");
-        return;
-    }
-    if ( $params->{help} ) {
-        $delegate_class->usage_message($delegate_class->help_usage_complete_text);
-        return;
-    }
-
-    my $command_object = $delegate_class->create(%$params);
-
-    unless ($command_object) {
-        # The delegate class should have emitted an error message.
-        # This is just in case the developer is sloppy, and the user will think the task did not fail.
-        print STDERR "Exiting.\n";
-        return;
-    }
-
-    $command_object->dump_status_messages(1);
-    $command_object->dump_warning_messages(1);
-    $command_object->dump_error_messages(1);
-    $command_object->dump_debug_messages(0);
-
-    my $rv = $command_object->execute($params);
-
-    if ($command_object->__errors__) {
-        $command_object->delete;
-    }
-
-    return $rv;
-}
-
-
-sub help_brief {
-    my $self = shift;
-    if (my $doc = $self->__meta__->doc) {
-        return $doc;
-    }
-    else {
-        my @parents = $self->__meta__->ancestry_class_metas;
-        for my $parent (@parents) {
-            if (my $doc = $parent->doc) {
-                return $doc;
-            }
-        }
-        return "";
-    }
-}
-
-sub is_sub_command_delegator {
-    return 1;
-}
-
 sub resolve_option_completion_spec {
     my $class = shift;
     my @completion_spec;
 
-    my @sub = eval { $class->sub_command_names};
+    my @sub = eval { $class->sub_command_names };
     if ($@) {
         $class->warning_message("Couldn't load class $class: $@\nSkipping $class...");
         return;
@@ -143,6 +60,22 @@ sub resolve_option_completion_spec {
     return \@completion_spec
 }
 
+sub help_brief {
+    my $self = shift;
+    if (my $doc = $self->__meta__->doc) {
+        return $doc;
+    }
+    else {
+        my @parents = $self->__meta__->ancestry_class_metas;
+        for my $parent (@parents) {
+            if (my $doc = $parent->doc) {
+                return $doc;
+            }
+        }
+        return "";
+    }
+}
+
 sub doc_help {
     my $self = shift;
 
@@ -236,40 +169,40 @@ sub sub_commands_table {
     return $tb;
 }
 
-sub help_sub_commands {
+sub _categorize_sub_commands {
     my $class = shift;
-    my %params = @_;
-    my $command_name_method = 'command_name_brief';
-    #my $command_name_method = ($params{brief} ? 'command_name_brief' : 'command_name');
     
     my @sub_command_classes = $class->sorted_sub_command_classes;
-
     my %categories;
-    my @categories;
+    my @order;
     for my $sub_command_class (@sub_command_classes) {
-        my $category = $sub_command_class->sub_command_category;
-        $category = '' if not defined $category;
         next if $sub_command_class->_is_hidden_in_docs();
-        my $sub_commands_within_category = $categories{$category};
-        unless ($sub_commands_within_category) {
-            if (defined $category and length $category) {
-                push @categories, $category;
+        my $category = $sub_command_class->sub_command_category || '';
+        unless (exists $categories{$category}) {
+            if ($category) {
+                push(@order, $category) 
+            } else {
+                unshift(@order, '');
             }
-            else {
-                unshift @categories,''; 
-            }
-            $sub_commands_within_category = $categories{$category} = [];
+            $categories{$category} = [];
         }
-        push @$sub_commands_within_category,$sub_command_class;
+        push(@{$categories{$category}}, $sub_command_class);
     }
 
+    return (\@order, \%categories);
+}
+    
+sub help_sub_commands {
+    my ($self, %params) = @_;
+    my ($order, $categories) = $self->_categorize_sub_commands(@_);
+    my $command_name_method = 'command_name_brief';
+
     no warnings;
-    local  $Text::Wrap::columns = 60;
+    local $Text::Wrap::columns = 60;
     
-    my $full_text = '';
     my @full_data;
-    for my $category (@categories) {
-        my $sub_commands_within_this_category = $categories{$category};
+    for my $category (@$order) {
+        my $sub_commands_within_this_category = $categories->{$category};
         my @data = map {
                 my @rows = split("\n",Text::Wrap::wrap('', ' ', $_->help_brief));
                 chomp @rows;
@@ -325,13 +258,34 @@ sub help_sub_commands {
     for my $row (@full_data) {
         for my $c (0..2) {
             $text .= ' ';
-            $text .= Term::ANSIColor::colored($row->[$c], $colors[$c]),
+            $text .= Term::ANSIColor::colored($row->[$c], $colors[$c]);
             $text .= ' ';
             $text .= ' ' x ($max_width_found[$c]-length($row->[$c]));
         }
         $text .= "\n";
     }
-    $DB::single = 1;        
+    return $text;
+}
+
+sub doc_sub_commands {
+    my $self = shift;
+    my ($order, $categories) = $self->_categorize_sub_commands(@_);
+    my $text = "";
+    my $indent_lvl = 4;
+    for my $category (@$order) {
+        my $category_name = ($category ? uc $category : "GENERAL");
+        $text .= "=head2 $category_name\n\n";
+        for my $cmd (@{$categories->{$category}}) {
+            $text .= "=over $indent_lvl\n\n";
+            my $name = $cmd->command_name_brief;
+            my $link = $cmd->command_name;
+            $link =~ s/ /-/g;
+            my $description = $cmd->help_brief;
+            $text .= "=item B<L<$name|$link>>\n\n=over 2\n\n=item $description\n\n=back\n\n";
+            $text .= "=back\n\nE<10>\n\n";
+        }
+    }
+
     return $text;
 }
 
@@ -357,41 +311,78 @@ sub sub_command_classes {
     return values %$mapping;
 }
 
+# For compatability with Command::V1-based callers
+sub is_sub_command_delegator {
+    return scalar(shift->sub_command_classes);
+}
+
 sub _build_sub_command_mapping {
     my $class = shift;
     $class = ref($class) || $class;
-    
+
     my $mapping;
     do {
         no strict 'refs';
         $mapping = ${ $class . '::SUB_COMMAND_MAPPING'};
     };
-    
+
     unless (ref($mapping) eq 'HASH') {
+        # for My::Foo::Command::* commands and sub-trees
         my $subdir = $class; 
         $subdir =~ s|::|\/|g;
 
+        # for My::Foo::*::Command sub-trees
+        my $class_above = $class;
+        $class_above =~ s/::Command//;
+        my $subdir2 = $class_above;
+        $subdir2 =~ s|::|/|g;
+
+        # check everywhere
         for my $lib (@INC) {
             my $subdir_full_path = $lib . '/' . $subdir;
-            next unless -d $subdir_full_path;
-            my @files = glob($subdir_full_path . '/*');
-            next unless @files;
-            for my $file (@files) {
-                my $basename = basename($file);
-                $basename =~ s/.pm$//;
-                my $sub_command_class_name = $class . '::' . $basename;
-                my $sub_command_class_meta = UR::Object::Type->get($sub_command_class_name);
-                unless ($sub_command_class_meta) {
-                    local $SIG{__DIE__};
-                    local $SIG{__WARN__};
-                    # until _use_safe is refactored to be permissive, use directly...
-                    eval "use $sub_command_class_name";
+
+            # find My::Foo::Command::*
+            if (-d $subdir_full_path) {
+                my @files = glob($subdir_full_path . '/*');
+                for my $file (@files) {
+                    my $basename = basename($file);
+                    $basename =~ s/.pm$// or next;
+                    my $sub_command_class_name = $class . '::' . $basename;
+                    my $sub_command_class_meta = UR::Object::Type->get($sub_command_class_name);
+                    unless ($sub_command_class_meta) {
+                        local $SIG{__DIE__};
+                        local $SIG{__WARN__};
+                        # until _use_safe is refactored to be permissive, use directly...
+                        print ">> $sub_command_class_name\n";
+                        eval "use $sub_command_class_name";
+                    }
+                    $sub_command_class_meta = UR::Object::Type->get($sub_command_class_name);
+                    next unless $sub_command_class_name->isa("Command");
+                    next if $sub_command_class_meta->is_abstract;
+                    my $name = $class->_command_name_for_class_word($basename); 
+                    $mapping->{$name} = $sub_command_class_name;
                 }
-                $sub_command_class_meta = UR::Object::Type->get($sub_command_class_name);
-                next unless $sub_command_class_name->isa("Command");
-                next if $sub_command_class_meta->is_abstract;
+            }
+
+            # find My::Foo::*::Command
+            $subdir_full_path = $lib . '/' . $subdir2;
+            my $pattern = $subdir_full_path . '/*/Command.pm';
+            my @paths = glob($pattern);
+            for my $file (@paths) {
+                next unless defined $file;
+                next unless length $file;
+                next unless -f $file;
+                my $last_word = File::Basename::basename($file);
+                $last_word =~ s/.pm$// or next;
+                my $dir = File::Basename::dirname($file);
+                my $second_to_last_word = File::Basename::basename($dir);
+                my $sub_command_class_name = $class_above . '::' . $second_to_last_word . '::' . $last_word;
+                next unless $sub_command_class_name->isa('Command');
+                next if $sub_command_class_name->__meta__->is_abstract;
+                my $basename = $second_to_last_word;
+                $basename =~ s/.pm$//;
                 my $name = $class->_command_name_for_class_word($basename); 
-                $mapping->{$name} = $sub_command_class_name;
+                $mapping->{$name} = $sub_command_class_name;                
             }
         }
     }
