@@ -2,7 +2,7 @@ package UR::BoolExpr::Template::Composite;
 
 use warnings;
 use strict;
-our $VERSION = "0.30"; # UR $VERSION;;
+our $VERSION = "0.33"; # UR $VERSION;;
 
 require UR;
 
@@ -19,15 +19,25 @@ sub get_underlying_rules_for_values {
     my @underlying_templates = $self->get_underlying_rule_templates();
     my @underlying_rules;
     for my $template (@underlying_templates) {
-        my $n = $template->num_values;
-        my $value_id = $template->values_to_value_id(splice(@values,0,$n));
-        my $rule_id = UR::BoolExpr->__meta__->resolve_composite_id_from_ordered_values($template->id,$value_id);
-        my $rule = UR::BoolExpr->get($rule_id);
+        my $n = $template->_variable_value_count;
+        my $rule = $template->get_rule_for_values(splice(@values,0,$n));
         push @underlying_rules, $rule;
     }
     return @underlying_rules;
 }
 
+sub _get_for_subject_class_name_and_logic_detail {
+    my $class = shift;
+    my $subject_class_name = shift;
+    my $logic_detail = shift;
+    my $constant_id = shift;
+    
+    my ($logic_type) = ($class =~ /^UR::BoolExpr::Template::(.*)/); 
+    my $id = $class->__meta__->resolve_composite_id_from_ordered_values($subject_class_name, $logic_type, $logic_detail, $constant_id);
+    
+    return $class->get($id);
+}
+
 # sub get_underlying_rule_templates {
 
 # sub specifies_value_for {
