@@ -1,42 +1,34 @@
-
 package UR::BoolExpr::Template::PropertyComparison::Equals;
-
 use strict;
 use warnings;
 use UR;
-our $VERSION = "0.30"; # UR $VERSION;
+our $VERSION = "0.33"; # UR $VERSION;
 
 UR::Object::Type->define(
     class_name  => __PACKAGE__, 
     is => ['UR::BoolExpr::Template::PropertyComparison'],
 );
 
-sub evaluate_subject_and_values {
-    my $self = shift;
-    my $subject = shift;
-    my $comparison_value = shift;    
-    my $property_name = $self->property_name;    
-    my @property_value = eval { $subject->$property_name; };
-    if ($@) {
-        $DB::single = 1;
-    }
+sub _compare {
+    my ($class,$comparison_value,@property_values) = @_;
+    
     no warnings 'uninitialized';
-    if (@property_value == 0) {
+    if (@property_values == 0) {
         return ($comparison_value eq '' ? 1 : '');
     }
 
     no warnings 'numeric';
     my $cv_is_number = Scalar::Util::looks_like_number($comparison_value);
 
-    foreach my $property_value ( @property_value ) {
+    foreach my $property_value ( @property_values ) {
         my $pv_is_number = Scalar::Util::looks_like_number($property_value);
-
         if ($pv_is_number and $cv_is_number) {
             return 1 if $property_value == $comparison_value;
         } else {
             return 1 if $property_value eq $comparison_value;
         }
     }
+
     return '';
 }
 
