@@ -4,20 +4,15 @@ package UR::BoolExpr::Template::PropertyComparison::Matches;
 use strict;
 use warnings;
 use UR;
-our $VERSION = "0.30"; # UR $VERSION;
+our $VERSION = "0.33"; # UR $VERSION;
 
 UR::Object::Type->define(
     class_name  => __PACKAGE__, 
     is => ['UR::BoolExpr::Template::PropertyComparison'],
 );
 
-sub evaluate_subject_and_values {
-    my $self = shift;
-    my $subject = shift;
-    my $comparison_value = shift;    
-    my $property_name = $self->property_name;    
-    my @property_value = $subject->$property_name;
-
+sub _compare {
+    my ($class,$comparison_value,@property_value) = @_;
     no warnings 'uninitialized';
     foreach my $property_value ( @property_value ) {
         return 1 if ( $property_value =~ m/$comparison_value/ );
