@@ -4,26 +4,21 @@ package UR::BoolExpr::Template::PropertyComparison::NotLike;
 use strict;
 use warnings;
 use UR;
-our $VERSION = "0.30"; # UR $VERSION;
+our $VERSION = "0.33"; # UR $VERSION;
 
 UR::Object::Type->define(
     class_name  => __PACKAGE__, 
     is => ['UR::BoolExpr::Template::PropertyComparison'],
 );
 
-sub evaluate_subject_and_values {
-    my $self = shift;
-    my $subject = shift;
-    my $comparison_value = shift;    
-    my $escape = shift;    
-    my $regex = $self->
+sub _compare {
+    my ($class,$comparison_value,@property_value) = @_;
+    my $escape = '\\';    
+    my $regex = $class->
         comparison_value_and_escape_character_to_regex(
             $comparison_value,
             $escape
         );
-    my $property_name = $self->property_name;    
-    my @property_value = $subject->$property_name;
-
     no warnings 'uninitialized';
     foreach my $property_value ( @property_value ) {
         return '' if ($property_value =~ $regex);
